@@ -21,13 +21,13 @@
  * Keyed list object interface commands
  */
 
-Tcl_Obj* TclX_NewKeyedListObj();
+MODULE_SCOPE Tcl_Obj* TclX_NewKeyedListObj();
 
-void TclX_KeyedListInit(Tcl_Interp*);
-int  TclX_KeyedListGet(Tcl_Interp*, Tcl_Obj*, const char*, Tcl_Obj**);
-int  TclX_KeyedListSet(Tcl_Interp*, Tcl_Obj*, const char*, Tcl_Obj*);
-int  TclX_KeyedListDelete(Tcl_Interp*, Tcl_Obj*, const char*);
-int  TclX_KeyedListGetKeys(Tcl_Interp*, Tcl_Obj*, const char*, Tcl_Obj**);
+MODULE_SCOPE void TclX_KeyedListInit(Tcl_Interp*);
+MODULE_SCOPE int  TclX_KeyedListGet(Tcl_Interp*, Tcl_Obj*, const char*, Tcl_Obj**);
+MODULE_SCOPE int  TclX_KeyedListSet(Tcl_Interp*, Tcl_Obj*, const char*, Tcl_Obj*);
+MODULE_SCOPE int  TclX_KeyedListDelete(Tcl_Interp*, Tcl_Obj*, const char*);
+MODULE_SCOPE int  TclX_KeyedListGetKeys(Tcl_Interp*, Tcl_Obj*, const char*, Tcl_Obj**);
 
 /*
  * Exported for usage in Sv_DuplicateObj. This is slightly
@@ -35,7 +35,7 @@ int  TclX_KeyedListGetKeys(Tcl_Interp*, Tcl_Obj*, const char*, Tcl_Obj**);
  * It does a proper deep-copy of the keyed list object.
  */
 
-void DupKeyedListInternalRepShared(Tcl_Obj*, Tcl_Obj*);
+MODULE_SCOPE void DupKeyedListInternalRepShared(Tcl_Obj*, Tcl_Obj*);
 
 #endif /* _KEYLIST_H_ */
 
