@@ -28,7 +28,7 @@
  * ----------------------------------------------------------------------------
  */
 
-#include "tclThread.h"
+#include "tclThreadInt.h"
 #include "threadSpCmd.h"
 
 /*
@@ -43,15 +43,6 @@
 #define SP_MUTEX   1  /* Any kind of mutex */
 #define SP_CONDV   2  /* The condition variable sync type */
 
-/*
- * Handle hiding of errorLine in 8.6
- */
-#if (TCL_MAJOR_VERSION == 8) && (TCL_MINOR_VERSION < 6)
-#define ERRORLINE(interp) ((interp)->errorLine)
-#else
-#define ERRORLINE(interp) (Tcl_GetErrorLine(interp))
-#endif
-
 /* 
  * Structure representing one sync primitive (mutex, condition variable). 
  * We use buckets to manage Tcl names of sync primitives. Each bucket
@@ -103,8 +94,9 @@ typedef struct _SpCondv {
 
 static int        initOnce;    /* Flag for initializing tables below */
 static Tcl_Mutex  initMutex;   /* Controls initialization of primitives */
-static SpBucket*  muxBuckets;  /* Maps mutex names/handles */
-static SpBucket*  varBuckets;  /* Maps condition variable names/handles */
+static SpBucket  muxBuckets[NUMSPBUCKETS];  /* Maps mutex names/handles */
+static SpBucket  varBuckets[NUMSPBUCKETS];  /* Maps condition variable
+					     * names/handles */
 
 /*
  * Functions implementing Tcl commands
@@ -215,7 +207,7 @@ ThreadMutexObjCmd(dummy, interp, objc, objv)
         Tcl_WrongNumArgs(interp, 1, objv, "option ?args?");
         return TCL_ERROR;
     }
-    ret = Tcl_GetIndexFromObj(interp, objv[1], cmdOpts, "option", 0, &opt);
+    ret = Tcl_GetIndexFromObjStruct(interp, objv[1], cmdOpts, sizeof(char *), "option", 0, &opt);
     if (ret != TCL_OK) {
         return TCL_ERROR;
     }
@@ -390,7 +382,7 @@ ThreadRWMutexObjCmd(dummy, interp, objc, objv)
         Tcl_WrongNumArgs(interp, 1, objv, "option ?args?");
         return TCL_ERROR;
     }
-    ret = Tcl_GetIndexFromObj(interp, objv[1], cmdOpts, "option", 0, &opt);
+    ret = Tcl_GetIndexFromObjStruct(interp, objv[1], cmdOpts, sizeof(char *), "option", 0, &opt);
     if (ret != TCL_OK) {
         return TCL_ERROR;
     }
@@ -550,7 +542,7 @@ ThreadCondObjCmd(dummy, interp, objc, objv)
         Tcl_WrongNumArgs(interp, 1, objv, "option ?args?");
         return TCL_ERROR;
     }
-    ret = Tcl_GetIndexFromObj(interp, objv[1], cmdOpts, "option", 0, &opt);
+    ret = Tcl_GetIndexFromObjStruct(interp, objv[1], cmdOpts, sizeof(char *), "option", 0, &opt);
     if (ret != TCL_OK) {
         return TCL_ERROR;
     }
@@ -771,7 +763,9 @@ ThreadEvalObjCmd(dummy, interp, objc, objv)
 
     if (ret == TCL_ERROR) {
         char msg[32 + TCL_INTEGER_SPACE];
-        sprintf(msg, "\n    (\"eval\" body line %d)", ERRORLINE(interp));
+        /* Next line generates a Deprecation warning when compiled with Tcl 8.6.
+         * See Tcl bug #3562640 */
+        sprintf(msg, "\n    (\"eval\" body line %d)", Tcl_GetErrorLine(interp));
         Tcl_AddObjErrorInfo(interp, msg, -1);
     }
 
@@ -1082,15 +1076,17 @@ Sp_Init (interp)
     if (!initOnce) {
         Tcl_MutexLock(&initMutex);
         if (!initOnce) {
-            int ii, buflen = sizeof(SpBucket) * (NUMSPBUCKETS);
-            char *buf  = Tcl_Alloc(2 * buflen);
-            muxBuckets = (SpBucket*)(buf);
-            varBuckets = (SpBucket*)(buf + buflen);
-            for (ii = 0; ii < 2 * (NUMSPBUCKETS); ii++) {
+            int ii;
+            for (ii = 0; ii < NUMSPBUCKETS; ii++) {
                 bucketPtr = &muxBuckets[ii];
                 memset(bucketPtr, 0, sizeof(SpBucket));
                 Tcl_InitHashTable(&bucketPtr->handles, TCL_STRING_KEYS);
             }
+            for (ii = 0; ii < NUMSPBUCKETS; ii++) {
+                bucketPtr = &varBuckets[ii];
+                memset(bucketPtr, 0, sizeof(SpBucket));
+                Tcl_InitHashTable(&bucketPtr->handles, TCL_STRING_KEYS);
+            }
             initOnce = 1;
         }
         Tcl_MutexUnlock(&initMutex);
