@@ -13,18 +13,15 @@
  * ----------------------------------------------------------------------------
  */
 
+#include "tclThreadInt.h"
 #include "threadSvCmd.h"
 
 #include "threadSvListCmd.h"    /* Shared variants of list commands */
 #include "threadSvKeylistCmd.h" /* Shared variants of list commands */
 #include "psGdbm.h"             /* The gdbm persistent store implementation */
 
-#ifdef NS_AOLSERVER
-# define HIDE_DOTNAMES       /* tsv::names cmd does not list .<name> arrays */
-#endif
-
 /*
- * Number of buckets to spread shared arrays into. Each bucket is 
+ * Number of buckets to spread shared arrays into. Each bucket is
  * associated with one mutex so locking a bucket locks all arrays
  * in that bucket as well. The number of buckets should be a prime.
  */
@@ -38,15 +35,6 @@
 
 #define OBJS_TO_ALLOC_EACH_TIME 100
 
-/*
- * Handle hiding of errorLine in 8.6
- */
-#if (TCL_MAJOR_VERSION == 8) && (TCL_MINOR_VERSION < 6)
-#define ERRORLINE(interp) ((interp)->errorLine)
-#else
-#define ERRORLINE(interp) (Tcl_GetErrorLine(interp))
-#endif
-
 /*
  * Reference to Tcl object types used in object-copy code.
  * Those are referenced read-only, thus no mutex protection.
@@ -64,7 +52,7 @@ static const Tcl_ObjType* stringObjTypePtr;
  * global symbol defined by Tcl. See Sv_Init.
  */
 
-char *Sv_tclEmptyStringRep = NULL;
+static char *Sv_tclEmptyStringRep = NULL;
 
 /*
  * Global variables used within this file.
@@ -81,9 +69,9 @@ static Tcl_Mutex  svMutex;      /* Protects inserts into above lists */
 static Tcl_Mutex  initMutex;    /* Serializes initialization issues */
 
 /*
- * The standard commands found in AOLserver nsv_* interface. 
- * For sharp-eye readers: the implementaion of the "lappend" command
- * is moved to new list-command package, since it realy belongs there.
+ * The standard commands found in NaviServer/AOLserver nsv_* interface.
+ * For sharp-eye readers: the implementation of the "lappend" command
+ * is moved to new list-command package, since it really belongs there.
  */
 
 static Tcl_ObjCmdProc SvObjObjCmd;
@@ -97,7 +85,7 @@ static Tcl_ObjCmdProc SvUnsetObjCmd;
 static Tcl_ObjCmdProc SvNamesObjCmd;
 
 /*
- * New commands added to 
+ * New commands added to
  * standard set of nsv_*
  */
 
@@ -124,6 +112,7 @@ static int DeleteArray(Array*);
 static void SvAllocateContainers(Bucket*);
 static void SvRegisterStdCommands(void);
 
+#define SV_FINALIZE
 #ifdef SV_FINALIZE
 static void SvFinalizeContainers(Bucket*);
 static void SvFinalize(ClientData);
@@ -131,8 +120,8 @@ static void SvFinalize(ClientData);
 
 static PsStore* GetPsStore(char *handle);
 
-static int SvObjDispatchObjCmd _ANSI_ARGS_ ((ClientData arg,
-            Tcl_Interp *interp, int objc, Tcl_Obj *const objv[]));
+static int SvObjDispatchObjCmd(ClientData arg,
+            Tcl_Interp *interp, int objc, Tcl_Obj *const objv[]);
 
 /*
  *-----------------------------------------------------------------------------
@@ -151,34 +140,36 @@ static int SvObjDispatchObjCmd _ANSI_ARGS_ ((ClientData arg,
  */
 
 void
-Sv_RegisterCommand(cmdName, objProc, delProc, clientData)
+Sv_RegisterCommand(cmdName, objProc, delProc)
     const char *cmdName;                /* Name of command to register */
     Tcl_ObjCmdProc *objProc;            /* Object-based command procedure */
     Tcl_CmdDeleteProc *delProc;         /* Command delete procedure */
-    ClientData clientData;              /* Private data ptr to pass to cmd */
 {
-    int len = strlen(cmdName) + strlen(TSV_CMD_PREFIX);
-    SvCmdInfo *newCmd = (SvCmdInfo*)Tcl_Alloc(sizeof(SvCmdInfo) + len + 1);
+    int len = strlen(cmdName) + strlen(TSV_CMD_PREFIX) + 1;
+    int len2 = strlen(cmdName) + strlen(TSV_CMD2_PREFIX) + 1;
+    SvCmdInfo *newCmd = (SvCmdInfo*)Tcl_Alloc(sizeof(SvCmdInfo) + len + len2);
 
     /*
      * Setup new command structure
      */
 
     newCmd->cmdName = (char*)((char*)newCmd + sizeof(SvCmdInfo));
+    newCmd->cmdName2 = newCmd->cmdName + len;
 
     newCmd->objProcPtr = objProc;
     newCmd->delProcPtr = delProc;
-    newCmd->clientData = clientData;
 
     /*
      * Rewrite command name. This is needed so we can
-     * easily turn-on the compatiblity with AOLserver
+     * easily turn-on the compatiblity with NaviServer/AOLserver
      * command names.
      */
 
     strcpy(newCmd->cmdName, TSV_CMD_PREFIX);
     strcat(newCmd->cmdName, cmdName);
     newCmd->name = newCmd->cmdName + strlen(TSV_CMD_PREFIX);
+    strcpy(newCmd->cmdName2, TSV_CMD2_PREFIX);
+    strcat(newCmd->cmdName2, cmdName);
 
     /*
      * Plug-in in shared list of commands.
@@ -261,7 +252,7 @@ void
 Sv_RegisterPsStore(psStorePtr)
      PsStore *psStorePtr;
 {
-    
+
     PsStore *psPtr = (PsStore*)Tcl_Alloc(sizeof(PsStore));
 
     *psPtr = *psStorePtr;
@@ -287,10 +278,10 @@ Sv_RegisterPsStore(psStorePtr)
  * Sv_GetContainer --
  *
  *      This is the workhorse of the module. It returns the container
- *      with the shared Tcl object. It also locks the container, so 
- *      when finished with operation on the Tcl object, one has to 
+ *      with the shared Tcl object. It also locks the container, so
+ *      when finished with operation on the Tcl object, one has to
  *      unlock the container by calling the Sv_PutContainer().
- *      If instructed, this command might also create new container 
+ *      If instructed, this command might also create new container
  *      with empty Tcl object.
  *
  * Results:
@@ -363,7 +354,7 @@ Sv_GetContainer(interp, objc, objv, retObj, offset, flags)
  *
  * Sv_PutContainer --
  *
- *      Releases the container obtained by the Sv_GetContainer. 
+ *      Releases the container obtained by the Sv_GetContainer.
  *
  * Results:
  *      A standard Tcl result.
@@ -403,7 +394,7 @@ Sv_PutContainer(interp, svObj, mode)
  *
  * Side effects;
  *      Memory gets allocated. Caller should free the return value of this
- *      function using Tcl_Free(). 
+ *      function using Tcl_Free().
  *
  *-----------------------------------------------------------------------------
  */
@@ -426,7 +417,7 @@ GetPsStore(char *handle)
 
     /*
      * Try to see wether some array is already bound to the
-     * same persistent storage address. 
+     * same persistent storage address.
      */
 
     for (i = 0; i < NUMBUCKETS; i++) {
@@ -477,7 +468,7 @@ GetPsStore(char *handle)
         }
     }
     Tcl_MutexUnlock(&svMutex);
-    
+
     if (delimiter) {
         *delimiter = ':';
     }
@@ -542,7 +533,7 @@ AcquireContainer(arrayPtr, key, flags)
  *
  *      Does some post-processing on the used container. This is mostly
  *      needed when the container has been modified and needs to be
- *      saved in the bound persistent storage. 
+ *      saved in the bound persistent storage.
  *
  * Results:
  *      A standard Tcl result
@@ -645,7 +636,7 @@ CreateContainer(arrayPtr, entryPtr, tclObj)
  *-----------------------------------------------------------------------------
  */
 
-static int 
+static int
 DeleteContainer(svObj)
     Container *svObj;
 {
@@ -662,7 +653,7 @@ DeleteContainer(svObj)
             if ((*psPtr->psDelete)(psPtr->psHandle, key) == -1) {
                 return TCL_ERROR;
             }
-        } 
+        }
         Tcl_DeleteHashEntry(svObj->entryPtr);
     }
 
@@ -759,13 +750,13 @@ LockArray(interp, array, flags)
  *-----------------------------------------------------------------------------
  */
 
-static int 
+static int
 FlushArray(arrayPtr)
     Array *arrayPtr;                    /* Name of array to flush */
 {
     Tcl_HashEntry *hPtr;
     Tcl_HashSearch search;
-    
+
     for (hPtr = Tcl_FirstHashEntry(&arrayPtr->vars, &search); hPtr;
          hPtr = Tcl_NextHashEntry(&search)) {
         if (DeleteContainer((Container*)Tcl_GetHashValue(hPtr)) != TCL_OK) {
@@ -826,7 +817,7 @@ CreateArray(bucketPtr, arrayName)
  *      Deletes the shared array.
  *
  * Results:
- *      A standard Tcl result. 
+ *      A standard Tcl result.
  *
  * Side effects:
  *      Memory gets reclaimed.
@@ -834,7 +825,7 @@ CreateArray(bucketPtr, arrayName)
  *-----------------------------------------------------------------------------
  */
 
-static int  
+static int
 DeleteArray(arrayPtr)
     Array *arrayPtr;
 {
@@ -1021,10 +1012,10 @@ Sv_DuplicateObj(objPtr)
                     }
                 }
                /*
-                * Assure at least string rep of the source 
-                * is present, which will be copied below. 
-                */  
-                if (found == 0 && objPtr->bytes == NULL 
+                * Assure at least string rep of the source
+                * is present, which will be copied below.
+                */
+                if (found == 0 && objPtr->bytes == NULL
                     && objPtr->typePtr->updateStringProc != NULL) {
                     (*objPtr->typePtr->updateStringProc)(objPtr);
                 }
@@ -1046,7 +1037,7 @@ Sv_DuplicateObj(objPtr)
                    (unsigned)objPtr->length);
         }
         dupPtr->length = objPtr->length;
-        dupPtr->bytes[objPtr->length] = '\0';        
+        dupPtr->bytes[objPtr->length] = '\0';
     }
 
     return dupPtr;
@@ -1120,8 +1111,8 @@ SvObjDispatchObjCmd(arg, interp, objc, objv)
  */
 
 static int
-SvObjObjCmd(dummy, interp, objc, objv)
-    ClientData dummy;                   /* Not used. */
+SvObjObjCmd(arg, interp, objc, objv)
+    ClientData arg;                     /* Just passed to subcommands. */
     Tcl_Interp *interp;                 /* Current interpreter. */
     int objc;                           /* Number of arguments. */
     Tcl_Obj *const objv[];              /* Argument objects. */
@@ -1165,7 +1156,7 @@ SvObjObjCmd(dummy, interp, objc, objv)
      */
 
     sprintf(buf, "::%p", (int*)svObj);
-    Tcl_CreateObjCommand(interp, buf, SvObjDispatchObjCmd, (int*)svObj, NULL);
+    Tcl_CreateObjCommand(interp, buf, (ClientData)SvObjDispatchObjCmd, (int*)svObj, arg);
     Tcl_ResetResult(interp);
     Tcl_SetObjResult(interp, Tcl_NewStringObj(buf, -1));
 
@@ -1203,7 +1194,7 @@ SvArrayObjCmd(arg, interp, objc, objv)
     Container *svObj, *elObj = NULL;
 
     static const char *opts[] = {
-        "set",  "reset", "get", "names", "size", "exists", "isbound", 
+        "set",  "reset", "get", "names", "size", "exists", "isbound",
         "bind", "unbind", NULL
     };
     enum options {
@@ -1227,7 +1218,7 @@ SvArrayObjCmd(arg, interp, objc, objv)
 
     Tcl_ResetResult(interp);
 
-    if (Tcl_GetIndexFromObj(interp,objv[1],opts,"option",0,&index) != TCL_OK) {
+    if (Tcl_GetIndexFromObjStruct(interp,objv[1],opts, sizeof(char *),"option",0,&index) != TCL_OK) {
         ret = TCL_ERROR;
 
     } else if (index == AEXISTS) {
@@ -1238,7 +1229,7 @@ SvArrayObjCmd(arg, interp, objc, objv)
             Tcl_SetBooleanObj(Tcl_GetObjResult(interp), 0);
         } else {
             Tcl_SetBooleanObj(Tcl_GetObjResult(interp), arrayPtr->psPtr ? 1:0);
-        }        
+        }
 
     } else if (index == ASIZE) {
         if (arrayPtr == NULL) {
@@ -1318,14 +1309,14 @@ SvArrayObjCmd(arg, interp, objc, objv)
          * This is more complex operation, requiring some clarification.
          *
          * When binding an already existing array, we walk the array
-         * first and store all key/value pairs found there in the 
+         * first and store all key/value pairs found there in the
          * persistent storage. Then we proceed with the below.
          *
          * When binding an non-existent array, we open the persistent
          * storage and cache all key/value pairs found there into tne
          * newly created shared array.
          */
-        
+
         PsStore *psPtr;
         int len;
         char *psurl, *key = NULL, *val = NULL;
@@ -1335,7 +1326,7 @@ SvArrayObjCmd(arg, interp, objc, objv)
             ret = TCL_ERROR;
             goto cmdExit;
         }
-        
+
         if (arrayPtr && arrayPtr->psPtr) {
             Tcl_AppendResult(interp, "array is already bound", NULL);
             ret = TCL_ERROR;
@@ -1346,7 +1337,7 @@ SvArrayObjCmd(arg, interp, objc, objv)
         psPtr = GetPsStore(psurl);
 
         if (psPtr == NULL) {
-            Tcl_AppendResult(interp, "can't open persistent storage on \"", 
+            Tcl_AppendResult(interp, "can't open persistent storage on \"",
                              psurl, "\"", NULL);
             ret = TCL_ERROR;
             goto cmdExit;
@@ -1485,8 +1476,8 @@ SvUnsetObjCmd(dummy, interp, objc, objv)
  */
 
 static int
-SvNamesObjCmd(dummy, interp, objc, objv)
-    ClientData dummy;                   /* Not used. */
+SvNamesObjCmd(aol, interp, objc, objv)
+    ClientData aol;                     /* !=0 when running in AOL */
     Tcl_Interp *interp;                 /* Current interpreter. */
     int objc;                           /* Number of arguments. */
     Tcl_Obj *const objv[];              /* Argument objects. */
@@ -1513,11 +1504,7 @@ SvNamesObjCmd(dummy, interp, objc, objv)
         hPtr = Tcl_FirstHashEntry(&bucketPtr->arrays, &search);
         while (hPtr) {
             char *key = Tcl_GetHashKey(&bucketPtr->arrays, hPtr);
-#ifdef HIDE_DOTNAMES
-            if (*key != '.' /* Hide .<name> arrays */ &&
-#else
-            if (1 &&
-#endif
+            if ((!aol || (*key != '.')) /* Hide .<name> arrays for AOL*/ &&
                 (pattern == NULL || Tcl_StringMatch(key, pattern))) {
                 Tcl_ListObjAppendElement(interp, resObj,
                         Tcl_NewStringObj(key, -1));
@@ -1636,7 +1623,7 @@ SvExistsObjCmd(arg, interp, objc, objv)
     switch (ret) {
     case TCL_BREAK: /* Array/key not found */
         Tcl_ResetResult(interp);
-        Tcl_SetBooleanObj(Tcl_GetObjResult(interp), 0); 
+        Tcl_SetBooleanObj(Tcl_GetObjResult(interp), 0);
         return TCL_OK;
     case TCL_ERROR:
         return TCL_ERROR;
@@ -2026,7 +2013,7 @@ SvLockObjCmd(dummy, interp, objc, objv)
     Bucket *bucketPtr;
     Array *arrayPtr = NULL;
 
-    /* 
+    /*
      * Syntax:
      *
      *     tsv::lock array arg ?arg ...?
@@ -2043,23 +2030,25 @@ SvLockObjCmd(dummy, interp, objc, objv)
 
     /*
      * Evaluate passed arguments as Tcl script. Note that
-     * Tcl_EvalObjEx throws away the passed object by 
+     * Tcl_EvalObjEx throws away the passed object by
      * doing an decrement reference count on it. This also
      * means we need not build object bytecode rep.
      */
-    
+
     if (objc == 3) {
         scriptObj = Tcl_DuplicateObj(objv[2]);
     } else {
         scriptObj = Tcl_ConcatObj(objc-2, objv + 2);
     }
-    
+
     Tcl_AllowExceptions(interp);
     ret = Tcl_EvalObjEx(interp, scriptObj, TCL_EVAL_DIRECT);
 
     if (ret == TCL_ERROR) {
         char msg[32 + TCL_INTEGER_SPACE];
-        sprintf(msg, "\n    (\"eval\" body line %d)", ERRORLINE(interp));
+        /* Next line generates a Deprecation warning when compiled with Tcl 8.6.
+         * See Tcl bug #3562640 */
+        sprintf(msg, "\n    (\"eval\" body line %d)", Tcl_GetErrorLine(interp));
         Tcl_AddObjErrorInfo(interp, msg, -1);
     }
 
@@ -2093,23 +2082,23 @@ static void
 SvRegisterStdCommands(void)
 {
     static int initialized = 0;
-    
+
     if (initialized == 0) {
         Tcl_MutexLock(&initMutex);
         if (initialized == 0) {
-            Sv_RegisterCommand("var",    SvObjObjCmd,    NULL, NULL);
-            Sv_RegisterCommand("object", SvObjObjCmd,    NULL, NULL);
-            Sv_RegisterCommand("set",    SvSetObjCmd,    NULL, NULL);
-            Sv_RegisterCommand("unset",  SvUnsetObjCmd,  NULL, NULL);
-            Sv_RegisterCommand("get",    SvGetObjCmd,    NULL, NULL);
-            Sv_RegisterCommand("incr",   SvIncrObjCmd,   NULL, NULL);
-            Sv_RegisterCommand("exists", SvExistsObjCmd, NULL, NULL);
-            Sv_RegisterCommand("append", SvAppendObjCmd, NULL, NULL);
-            Sv_RegisterCommand("array",  SvArrayObjCmd,  NULL, NULL);
-            Sv_RegisterCommand("names",  SvNamesObjCmd,  NULL, NULL);
-            Sv_RegisterCommand("pop",    SvPopObjCmd,    NULL, NULL);
-            Sv_RegisterCommand("move",   SvMoveObjCmd,   NULL, NULL);
-            Sv_RegisterCommand("lock",   SvLockObjCmd,   NULL, NULL);
+            Sv_RegisterCommand("var",    SvObjObjCmd,    NULL);
+            Sv_RegisterCommand("object", SvObjObjCmd,    NULL);
+            Sv_RegisterCommand("set",    SvSetObjCmd,    NULL);
+            Sv_RegisterCommand("unset",  SvUnsetObjCmd,  NULL);
+            Sv_RegisterCommand("get",    SvGetObjCmd,    NULL);
+            Sv_RegisterCommand("incr",   SvIncrObjCmd,   NULL);
+            Sv_RegisterCommand("exists", SvExistsObjCmd, NULL);
+            Sv_RegisterCommand("append", SvAppendObjCmd, NULL);
+            Sv_RegisterCommand("array",  SvArrayObjCmd,  NULL);
+            Sv_RegisterCommand("names",  SvNamesObjCmd,  NULL);
+            Sv_RegisterCommand("pop",    SvPopObjCmd,    NULL);
+            Sv_RegisterCommand("move",   SvMoveObjCmd,   NULL);
+            Sv_RegisterCommand("lock",   SvLockObjCmd,   NULL);
             initialized = 1;
         }
         Tcl_MutexUnlock(&initMutex);
@@ -2148,7 +2137,7 @@ Sv_Init (interp)
     Sv_RegisterKeylistCommands();
 
     /*
-     * Register standard (nsv_* compatible) and our 
+     * Register standard (nsv_* compatible) and our
      * own extensive set of list manipulating commands
      */
 
@@ -2172,7 +2161,11 @@ Sv_Init (interp)
 
     for (cmdPtr = svCmdInfo; cmdPtr; cmdPtr = cmdPtr->nextPtr) {
         Tcl_CreateObjCommand(interp, cmdPtr->cmdName, cmdPtr->objProcPtr,
-                (ClientData)cmdPtr->clientData, (Tcl_CmdDeleteProc*)0);
+                (ClientData)0, (Tcl_CmdDeleteProc*)0);
+#ifdef NS_AOLSERVER
+        Tcl_CreateObjCommand(interp, cmdPtr->cmdName2, cmdPtr->objProcPtr,
+                (ClientData)1, (Tcl_CmdDeleteProc*)0);
+#endif
     }
 
     /*
@@ -2183,6 +2176,8 @@ Sv_Init (interp)
         Tcl_MutexLock(&bucketsMutex);
         if (buckets == NULL) {
             buckets = (Bucket *)Tcl_Alloc(sizeof(Bucket) * NUMBUCKETS);
+	    Tcl_CreateExitHandler(SvFinalize, NULL);
+
             for (i = 0; i < NUMBUCKETS; ++i) {
                 bucketPtr = &buckets[i];
                 memset(bucketPtr, 0, sizeof(Bucket));
@@ -2213,16 +2208,9 @@ Sv_Init (interp)
 
     return TCL_OK;
 }
-
-int Sv_SafeInit (interp)
-    Tcl_Interp *interp;
-{
-    return (Sv_Init(interp));
-}
-
 
 #ifdef SV_FINALIZE
-/* 
+/*
  * Left for reference, but unused since multithreaded finalization is
  * unsolvable in the general case. Brave souls can revive this by
  * installing a late exit handler on Thread's behalf, bringing the
@@ -2267,7 +2255,7 @@ SvFinalize (clientData)
                 Bucket *bucketPtr = &buckets[i];
                 hashPtr = Tcl_FirstHashEntry(&bucketPtr->arrays, &search);
                 while (hashPtr != NULL) {
-                    Array *arrayPtr = (Array*)Tcl_GetHashValue(hashPtr); 
+                    Array *arrayPtr = (Array*)Tcl_GetHashValue(hashPtr);
                     UnlockArray(arrayPtr);
                     DeleteArray(arrayPtr);
                     hashPtr = Tcl_NextHashEntry(&search);
