@@ -9,8 +9,8 @@
 #ifndef _KEYLISTCMDS_H_
 #define _KEYLISTCMDS_H_
 
-void Sv_RegisterKeylistCommands(void);
-void TclX_KeyedListInit(Tcl_Interp *interp);
+MODULE_SCOPE void Sv_RegisterKeylistCommands(void);
+MODULE_SCOPE void TclX_KeyedListInit(Tcl_Interp *interp);
 
 #endif /* _KEYLISTCMDS_H_ */
 
